// MainFrm.cpp : implementation of the CMainFrame class
//

#include "stdafx.h"
#include "Demo.h"
#include "MPIChildFrame.h"
#include "MPIDocTemplate.h"
#include "MainFrm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif


// CMainFrame

IMPLEMENT_DYNAMIC(CMainFrame, CMDIFrameWnd)

BEGIN_MESSAGE_MAP(CMainFrame, CMDIFrameWnd)
	ON_WM_CREATE()
	ON_UPDATE_COMMAND_UI_RANGE(ID_MPI_FIRST, ID_MPI_THIRD, OnMPIUpdate)
	ON_COMMAND_RANGE(ID_MPI_FIRST, ID_MPI_THIRD, OnMPICommand)
	ON_WM_MENUCHAR()
	ON_WM_SYSCOMMAND()
	ON_WM_ACTIVATE()
	ON_WM_SETTINGCHANGE()
END_MESSAGE_MAP()

static UINT indicators[] =
{
	ID_SEPARATOR,           // status line indicator
	ID_INDICATOR_CAPS,
	ID_INDICATOR_NUM,
	ID_INDICATOR_SCRL,
};


// CMainFrame construction/destruction

CMainFrame::CMainFrame()
{
}

CMainFrame::~CMainFrame()
{
}


int CMainFrame::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	if (CMDIFrameWnd::OnCreate(lpCreateStruct) == -1)
		return -1;
	
    GetMenu()->DestroyMenu();
    SetMenu(NULL);

    if (!m_wndMPIBar.Create(this, AFX_IDW_TOOLBAR+6) ||
        !m_wndMPIBar.LoadToolBar(IDR_MPIBAR, AILS_OLD))
    {
        TRACE0("Failed to create MPI toolbar\n");
        return -1;      // fail to create
    }

    if (!m_wndToolBar.Create(this, AFX_IDW_TOOLBAR) ||
        !m_wndToolBar.LoadToolBar(IDR_MAINFRAME, AILS_OLD))
    {
        TRACE0("Failed to create toolbar\n");
        return -1;      // fail to create
    }

    if (!m_wndMenuBar.Create(this) ||
        !m_wndMenuBar.LoadMenuBar(IDR_MAINFRAME, AILS_OLD))
    {
        TRACE0("Failed to create menubar\n");
        return -1;      // fail to create
    }

    m_wndMenuBar.LoadToolBar(IDR_MAINFRAME);
    m_wndMenuBar.LoadToolBar(IDR_MPIBAR);

	if (!m_wndReBar.Create(this, RBS_BANDBORDERS,
		WS_CHILD | WS_VISIBLE | WS_CLIPCHILDREN | WS_CLIPSIBLINGS | CBRS_ALIGN_TOP)
		|| !m_wndReBar.AddBar(&m_wndMenuBar)
		|| !m_wndReBar.AddBar(&m_wndMPIBar, NULL, (CBitmap*)NULL, RBBS_BREAK)
  		|| !m_wndReBar.AddBar(&m_wndToolBar, NULL, (CBitmap*)NULL, RBBS_BREAK))
  {
        TRACE0("Failed to create rebar\n");
        return -1;      // fail to create
    }

	if (!m_wndStatusBar.Create(this) ||
		!m_wndStatusBar.SetIndicators(indicators,
		  sizeof(indicators)/sizeof(UINT)))
	{
		TRACE0("Failed to create status bar\n");
		return -1;      // fail to create
	}

	return 0;
}

BOOL CMainFrame::PreCreateWindow(CREATESTRUCT& cs)
{
	if( !CMDIFrameWnd::PreCreateWindow(cs) )
		return FALSE;

	return TRUE;
}


// CMainFrame diagnostics

#ifdef _DEBUG
void CMainFrame::AssertValid() const
{
	CMDIFrameWnd::AssertValid();
}

void CMainFrame::Dump(CDumpContext& dc) const
{
	CMDIFrameWnd::Dump(dc);
}

#endif //_DEBUG


// CMainFrame message handlers


void CMainFrame::OnUpdateFrameTitle(BOOL bAddToTitle)
{
	CMDIFrameWnd::OnUpdateFrameTitle(FALSE);
}

void CMainFrame::UpdateMenu(HMENU hMenu)
{
	SetMenu(NULL);

	if (hMenu)
		m_wndMenuBar.AttachMenu(hMenu);
}

void CMainFrame::OnMPIUpdate(CCmdUI* pCmdUI)
{
	pCmdUI->Enable();

	CMPIChildFrame* pFrame = (CMPIChildFrame*)MDIGetActive();

	if (pFrame)
	{
		POSITION pos = AfxGetApp()->GetFirstDocTemplatePosition();
		CMPIDocTemplate* pDocTemplate = (CMPIDocTemplate*)AfxGetApp()->GetNextDocTemplate(pos);

		ASSERT_KINDOF(CMPIDocTemplate, pDocTemplate);

		int nIndex = pDocTemplate->FindChildFrame(pFrame);

		pCmdUI->SetCheck(nIndex == (int)pCmdUI->m_nID - ID_MPI_FIRST);
	}
}

void CMainFrame::OnMPICommand(UINT nID)
{
	POSITION pos = AfxGetApp()->GetFirstDocTemplatePosition();
	CMPIDocTemplate* pDocTemplate = (CMPIDocTemplate*)AfxGetApp()->GetNextDocTemplate(pos);

	ASSERT_KINDOF(CMPIDocTemplate, pDocTemplate);

	CMPIChildFrame* pFrame = pDocTemplate->GetChildFrame(nID - ID_MPI_FIRST);

	ASSERT_KINDOF(CMPIChildFrame, pFrame);

	MDIActivate(pFrame);
}


BOOL CMainFrame::PreTranslateMessage(MSG* pMsg)	
{
	if (pMsg->message == WM_SYSKEYDOWN && pMsg->wParam == VK_MENU)
		m_wndMenuBar.SetPrefix(TRUE);
	else if	(pMsg->message == WM_KEYUP && pMsg->wParam == VK_MENU)
		m_wndMenuBar.SetPrefix(FALSE);

	return CFrameWnd::PreTranslateMessage(pMsg);
}

LRESULT	CMainFrame::OnMenuChar(UINT	nChar, UINT	nFlags,	CMenu* pMenu) 
{
	if (m_wndMenuBar.OpenMenu(nChar))
		return -1;

	return CFrameWnd::OnMenuChar(nChar,	nFlags,	pMenu);
}

void CMainFrame::OnSysCommand(UINT nID,	LPARAM lParam) 
{
	if (nID	== SC_KEYMENU && m_wndMenuBar.OnKeyMenu((UINT)lParam))
		return;

	CFrameWnd::OnSysCommand(nID, lParam);
}

void CMainFrame::OnActivate(UINT nState, CWnd* pWndOther, BOOL bMinimized) 
{
	m_wndMenuBar.Activate(nState !=	WA_INACTIVE);

	CFrameWnd::OnActivate(nState, pWndOther, bMinimized);
}

void CMainFrame::OnSettingChange(UINT uFlags, LPCTSTR lpszSection) 
{
	m_wndMenuBar.UpdateSettings();

	CFrameWnd::OnSettingChange(uFlags, lpszSection);
}

